__title__ = "dissertate"
__author__ = "John Bjorn Nelson (generativist)"
__email__ = "jbn@abreka.com"
__description__ = "A package and CLI for writing dissertations."
__uri__ = "https://github.com/jbn/dissertate"
__doc__ = __description__ + " <" + __uri__ + ">"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2017 John Bjorn Nelson"
__version__ = "0.0.1"
